'sucess' -> 'success' in the lastest source code.
- src/gnu/egcs/gcc/java/verify.c.orig Sun Dec 8 01:44:34 2002
+++ src/gnu/egcs/gcc/java/verify.c Sun Dec 8 01:46:33 2002
@@ -62,7 +62,7 @@
/* Note that TARGET_LABEL is a possible successor instruction.
Merge the type state etc.
- Return NULL on sucess, or an error message on failure. */
+ Return NULL on success, or an error message on failure. */
static const char *
check_pending_block (target_label)
@@ -340,7 +340,7 @@
#define BCODE byte_ops
/* Verify the bytecodes of the current method.
- Return 1 on sucess, 0 on failure. */
+ Return 1 on success, 0 on failure. */
int
verify_jvm_instructions (jcf, byte_ops, length)
JCF* jcf;
--- src/gnu/usr.bin/binutils/gas/atof-generic.c.orig Sun Dec 8 01:47:33 2002
+++ src/gnu/usr.bin/binutils/gas/atof-generic.c Sun Dec 8 01:48:34 2002
@@ -472,7 +472,7 @@
{
/*
* Compute the mantssa (& exponent) of the power of 10.
- * If sucessful, then multiply the power of 10 by the digits
+ * If successful, then multiply the power of 10 by the digits
* giving return_binary_mantissa and return_binary_exponent.
*/
--- src/gnu/usr.bin/cvs/src/filesubr.c.orig Sun Dec 8 01:51:55 2002
+++ src/gnu/usr.bin/cvs/src/filesubr.c Sun Dec 8 01:53:05 2002
@@ -767,7 +767,7 @@
if (fd == -1) fp = NULL;
else if ((fp = CVS_FDOPEN (fd, "w+")) == NULL)
{
- /* attempt to close and unlink the file since mkstemp returned sucessfully and
+ /* attempt to close and unlink the file since mkstemp returned successfully and
* we believe it's been created and opened
*/
int save_errno = errno;
--- src/usr.bin/make/lst.lib/lstSucc.c.orig Sun Dec 8 02:30:50 2002
+++ src/usr.bin/make/lst.lib/lstSucc.c Sun Dec 8 02:31:20 2002
@@ -49,7 +49,7 @@
/*-
*-----------------------------------------------------------------------
* Lst_Succ --
- * Return the sucessor to the given node on its list.
+ * Return the successor to the given node on its list.
*
* Results:
* The successor of the node, if it exists.
--- src/usr.bin/sup/src/supcmain.c.orig Sun Dec 8 02:32:04 2002
+++ src/usr.bin/sup/src/supcmain.c Sun Dec 8 02:32:33 2002
@@ -272,7 +272,7 @@
* the user and group specified by the remote system. Changed
* execute code to invalidate collection if execute command returns
* with a non-zero exit status. Added support for execv() of
- * original arguments of supfile is upgraded sucessfully. Changed
+ * original arguments of supfile is upgraded successfully. Changed
* copyfile to always use a temp file if possible. [V5.7]
*
- 04-Jan-86 Glenn Marcy (gm0w) at Carnegie-Mellon University
--- src/usr.sbin/ypserv/revnetgroup/parse_netgroup.c.orig Sun Dec 8 02:33:04 2002
+++ src/usr.sbin/ypserv/revnetgroup/parse_netgroup.c Sun Dec 8 02:33:58 2002
@@ -204,7 +204,7 @@
#ifdef DEBUG
/*
- This error message is largely superflous since the
- * code handles the error condition sucessfully, and
+ * code handles the error condition successfully, and
- spewing it out from inside libc can actually hose
- certain programs.
*/
--- src/sys/arch/amiga/dev/if_es.c.orig Sun Dec 8 02:34:36 2002
+++ src/sys/arch/amiga/dev/if_es.c Sun Dec 8 02:35:15 2002
@@ -466,8 +466,8 @@
- This shouldn't have happened: IST_TX indicates
- the TX completion FIFO is not empty, but the
- status for the packet on the completion FIFO
- * shows that the transmit was sucessful. Since
- * AutoRelease is being used, a sucessful transmit
+ * shows that the transmit was successful. Since
+ * AutoRelease is being used, a successful transmit
- should not result in a packet on the completion
- FIFO. Also, that packet doesn't seem to want
- to be acknowledged. If this occurs, just reset
--- src/sys/arch/hp300/dev/hil.c.orig Sun Dec 8 02:35:43 2002
+++ src/sys/arch/hp300/dev/hil.c Sun Dec 8 02:36:18 2002
@@ -968,7 +968,7 @@
- Copy data to queue.
- If this is the first queue we construct the packet
- with length, timestamp and poll buffer data.
- * For second and sucessive packets we just duplicate
+ * For second and successive packets we just duplicate
- the first packet.
*/
pp = (u_char *) &hq->hil_event[hq->hil_evqueue.tail];
--- src/sys/arch/hp300/hp300/trap.c.orig Sun Dec 8 02:36:51 2002
+++ src/sys/arch/hp300/hp300/trap.c Sun Dec 8 02:37:13 2002
@@ -247,7 +247,7 @@
- If any writeback fails, go back and attempt signal delivery.
- unless we have already been here and attempted the writeback
- (e.g. bad address with user ignoring SIGSEGV). In that case
- * we just return to the user without sucessfully completing
+ * we just return to the user without successfully completing
- the writebacks. Maybe we should just drop the sucker?
*/
if (cputype == CPU_68040 && fp->f_format == FMT7) {
--- src/sys/arch/mvme68k/mvme68k/trap.c.orig Sun Dec 8 02:37:43 2002
+++ src/sys/arch/mvme68k/mvme68k/trap.c Sun Dec 8 02:38:04 2002
@@ -225,7 +225,7 @@
- If any writeback fails, go back and attempt signal delivery.
- unless we have already been here and attempted the writeback
- (e.g. bad address with user ignoring SIGSEGV). In that case
- * we just return to the user without sucessfully completing
+ * we just return to the user without successfully completing
- the writebacks. Maybe we should just drop the sucker?
*/
if (mmutype == MMU_68040 && fp->f_format == FMT7) {
--- src/sys/arch/mvme88k/ddb/db_trace.c.orig Sun Dec 8 02:38:56 2002
+++ src/sys/arch/mvme88k/ddb/db_trace.c Sun Dec 8 02:39:23 2002
@@ -616,7 +616,7 @@
if (!db_trace_get_val(check_addr + 4, &inst))
continue;
if (ST_R1_R31_IMM(instr))
- break; /* sucess */
+ break; /* success */
#else
/*
- Latest GCC optimizer is just too good... the store
--- src/sys/dev/ic/aic7xxx.c.orig Sun Dec 8 02:39:50 2002
+++ src/sys/dev/ic/aic7xxx.c Sun Dec 8 02:40:18 2002
@@ -1109,7 +1109,7 @@
/*
- Although the driver does not care about the
- 'Selection in Progress' status bit, the busy
- * LED does. SELINGO is only cleared by a sucessfull
+ * LED does. SELINGO is only cleared by a successfull
- selection, so we must manually clear it to insure
- the LED turns off just incase no future successful
- selections occur (e.g. no devices on the bus).
Received on Sun Dec 8 16:37:29 2002
This archive was generated by hypermail 2.1.8
: Wed Aug 23 2006 - 13:29:38 EDT
|
--- src/gnu/usr.bin/cvs/zlib/contrib/minizip/unzip.c.orig Sun Dec 8 01:56:25 2002
+++ src/gnu/usr.bin/cvs/zlib/contrib/minizip/unzip.c Sun Dec 8 02:11:57 2002
@@ -129,7 +129,7 @@
/* ===========================================================================
Read a byte from a gz_stream; update next_in and avail_in. Return EOF
for end of file.
- IN assertion: the stream s has been sucessfully opened for reading.
+ IN assertion: the streams has been successfully opened for reading.
*/
- src/gnu/usr.bin/cvs/zlib/gzio.c.orig Sun Dec 8 01:54:13 2002
+++ src/gnu/usr.bin/cvs/zlib/gzio.c Sun Dec 8 02:07:06 2002
@@ -231,7 +231,7 @@
/* ===========================================================================
Read a byte from a gz_stream; update next_in and avail_in. Return EOF
for end of file.
- IN assertion: the stream s has been sucessfully opened for reading.
+ IN assertion: the streams has been successfully opened for reading.
*/
local int get_byte(s)
gz_stream *s;
@@ -256,7 +256,7 @@
mode to transparent if the gzip magic header is not present; set s->err
to Z_DATA_ERROR if the magic header is present but the rest of the header
is incorrect.
- IN assertion: the stream s has already been created sucessfully;
+ IN assertion: the streams has already been created successfully;
s->stream.avail_in is zero for the first time, but may be non-zero
for concatenated .gz files.
*/
- src/gnu/usr.bin/texinfo/makeinfo/node.c.orig Sun Dec 8 02:23:55 2002
+++ src/gnu/usr.bin/texinfo/makeinfo/node.c Sun Dec 8 02:24:23 2002
@@ -1797,7 +1797,7 @@
}
}
/* We have sucessfully created the subfiles. Now write out the
original again. We must use `output_stream', or
write_tag_table_indirect () won't know where to place the output. */
output_stream = fopen (filename, "w");
- src/gnu/usr.sbin/sendmail/sendmail/milter.c.orig Sun Dec 8 02:25:36 2002
+++ src/gnu/usr.sbin/sendmail/sendmail/milter.c Sun Dec 8 02:26:13 2002
@@ -549,7 +549,7 @@
- e -- current envelope.
**
- Returns:
-** connected socket if sucessful && !parseonly,
+** connected socket if successful && !parseonly,
- 0 upon parse success if parseonly,
- -1 otherwise.
*/
- src/lib/libz/gzio.c.orig Sun Dec 8 02:26:50 2002
+++ src/lib/libz/gzio.c Sun Dec 8 02:28:04 2002
@@ -231,7 +231,7 @@
/* ===========================================================================
Read a byte from a gz_stream; update next_in and avail_in. Return EOF
for end of file.
- IN assertion: the stream s has been sucessfully opened for reading.
+ IN assertion: the streams has been successfully opened for reading.
*/
local int get_byte(s)
gz_stream *s;
@@ -256,7 +256,7 @@
mode to transparent if the gzip magic header is not present; set s->err
to Z_DATA_ERROR if the magic header is present but the rest of the header
is incorrect.
- IN assertion: the stream s has already been created sucessfully;
+ IN assertion: the streams has already been created successfully;
s->stream.avail_in is zero for the first time, but may be non-zero
for concatenated .gz files.
*/
- src/usr.bin/aucat/aucat.c.orig Sun Dec 8 02:29:14 2002
+++ src/usr.bin/aucat/aucat.c Sun Dec 8 02:30:00 2002
@@ -42,7 +42,7 @@
/* function playfile: given a file which is positioned at the beginning
* of what is assumed to be an .au data stream copy it out to the audio
- * device. Return 0 on sucess, -1 on failure.
+ * device. Return 0 on success, -1 on failure.
*/
int
playfile(fd, dev)
@@ -1797,7 +1797,7 @@
}
}
- /* We have sucessfully created the subfiles. Now write out the
+ /* We have successfully created the subfiles. Now write out the
original again. We must use `output_stream', or
write_tag_table_indirect () won't know where to place the output. */